==> haskell-th-lift-0.8.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift
version:              0.8.2
visibility:           public
id:                   th-lift-0.8.2-47INKJD6iIF1IlUc8HcOrC
key:                  th-lift-0.8.2-47INKJD6iIF1IlUc8HcOrC
license:              BSD-3-Clause
copyright:
    © 2006 Ian Lynagh, © 2010-2019 Mathieu Boespflug, © 2019 Ryan Scott

maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ian Lynagh
homepage:             http://github.com/RyanGlScott/th-lift
synopsis:             Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s @Lift@ class for datatypes using @TemplateHaskell@.
    The functionality in this package has largely been subsumed by the
    @DeriveLift@ language extension, which is available in GHC 8.0 and later
    versions. This package can still be useful as a uniform way to derive
    @Lift@ instances that is backwards-compatible with older GHCs.

    The following libraries are related:

    * The <https://hackage.haskell.org/package/th-orphans th-orphans> package
    provides instances for @template-haskell@ syntax types.

    * The <http://hackage.haskell.org/package/th-lift-instances th-lift-instances>
    package provides @Lift@ instances for types in @base@, @text@,
    @bytestring@, @vector@, etc. Some of these instances are only provided for
    old versions of their respective libraries, as the same @Lift@ instances
    are also present upstream on newer versions.

category:             Language
abi:                  d1af48498d55dc866692267659c04aba
exposed:              True
exposed-modules:
    Language.Haskell.TH.Lift Language.Haskell.TH.Lift.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-lift-0.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-lift-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift
hs-libraries:         HSth-lift-0.8.2-47INKJD6iIF1IlUc8HcOrC
depends:
    base-4.15.1.0 ghc-prim-0.7.0 template-haskell-2.17.0.0
    th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp

haddock-interfaces:   /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html:         /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-0.8.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift
version:              0.8.3
visibility:           public
id:                   th-lift-0.8.3-1aK8XV103WS4XWxJH7X1xy
key:                  th-lift-0.8.3-1aK8XV103WS4XWxJH7X1xy
license:              BSD-3-Clause
copyright:
    © 2006 Ian Lynagh, © 2010-2019 Mathieu Boespflug, © 2019 Ryan Scott

maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ian Lynagh
homepage:             http://github.com/RyanGlScott/th-lift
synopsis:             Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s @Lift@ class for datatypes using @TemplateHaskell@.
    The functionality in this package has largely been subsumed by the
    @DeriveLift@ language extension, which is available in GHC 8.0 and later
    versions. This package can still be useful as a uniform way to derive
    @Lift@ instances that is backwards-compatible with older GHCs.

    The following libraries are related:

    * The <https://hackage.haskell.org/package/th-orphans th-orphans> package
    provides instances for @template-haskell@ syntax types.

    * The <http://hackage.haskell.org/package/th-lift-instances th-lift-instances>
    package provides @Lift@ instances for types in @base@, @text@,
    @bytestring@, @vector@, etc. Some of these instances are only provided for
    old versions of their respective libraries, as the same @Lift@ instances
    are also present upstream on newer versions.

category:             Language
abi:                  fb67e2671e23f949c42cf03f9749b0b7
exposed:              True
exposed-modules:
    Language.Haskell.TH.Lift Language.Haskell.TH.Lift.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-lift-0.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-lift-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift
hs-libraries:         HSth-lift-0.8.3-1aK8XV103WS4XWxJH7X1xy
depends:
    base-4.15.1.0 ghc-prim-0.7.0 template-haskell-2.17.0.0
    th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp

haddock-interfaces:   /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html:         /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
